==> un-applet_1.3.2_all.tar.bz2: un-applet_1.3.2_all/usr/share/un-applet/TkTray.py <==
import Tkinter
'''Tktray  is  an extension that is able to create system tray icons.
It follows http://www.freedesktop.org specifications when looking up
the system tray manager. This protocol is supported by modern versions
of KDE and Gnome panels, and by some other panel-like application.'''


class Icon(Tkinter.BaseWidget, Tkinter.Wm):
    def __init__(self, master=None, menu=True, tooltip=None, cnf={}, **kw):
        '''Create a new icon for the system tray. The application managing the
        system tray is notified about the new icon. It normally results in the
        icon being added to the tray. If there is no system tray at the icon
        creation time, the icon will be invisible. When a new system tray
        appears, the icon will be added to it. Since tktray 1.3, if the tray
        crashes and destroys your icon, it will be recreated on a new system
        tray when it's available.
        OPTIONS:
        class_
            WM_CLASS attribute for icon window. Tray manager may use class
            name to remember icon position or other attributes. This name may
            be used for event binding as well. For now, real icon window is
            distinct from the user-specified widget: it may be recreated and
            destroyed several times during icon lifetime, when a system tray
            crashes, terminates, disappears or appears. However, tktray tries
            to forward click and motion events from this inner window to user
            widget, so event bindings on widget name should work as they used
            to. This option applies to a real icon window, not to a
            user-visible widget, so don't rely on it to set widget defaults
            from an option database: the standard "TrayIcon" class name is
            used for it.
        docked
            boolean indicating whether the real icon window should be embedded
            into a tray when it exists. Think of it as a heavier version of
            -visible option: there is a guarantee that no place for icon will
            be reserved on any tray.
        image
            image to show in the system tray. Since tktray 1.3, image type
            PhotoImage is not mandatory anymore. Icon will be automatically
            redrawn on any image modifications. For Tk, deleting an image and
            creating an image with the same name later is a kind of image
            modification, and tktray follows this convention. Photo image
            operations that modify existing image content are another example
            of events triggering redisplay. Requested size for icon is set
            according to the image's width and height, but obeying
            (or disobeying) this request is left for the tray.
        menu
            boolean value indicating whether a context menu for the icon
            should be created on initialization. If True a menu is created
            and will pop up on <Button-3> events over the tray icon. The menu
            is of the type Tkinter.Menu and can be accessed through the
            tray icon's menu attribute.
        shape
            used to put a nonrectangular shape on an icon window.
            Ignored for compatibility.
        visible
            boolean value indicating whether the icon must be visible. The
            system tray manager continues to manage the icon whether it is
            visible or not. Thus when invisible icon becomes visible, its
            position on the system tray is likely to remain the same. Tktray
            currently tries to find a tray and embed into it as soon as
            possible, whether -visible is true or not. _XEMBED_INFO property
            is set for embedded window: a tray should show or hide an icon
            depending on this property. There may be, and indeed are,
            incomplete tray implementations ignoring _XEMBED_INFO
            (ex. docker). Gnome-panel "unmaps" an icon by making it one pixel
            wide, that might to be what you expect. For those implementations,
            the place for an icon will be reserved but no image will be
            displayed: tktray takes care of it. Tktray also blocks mouse event
            forwarding for invisible icons, so you may be confident that no
            <Button> bindings will be invoked at this time.
        WINDOW MANAGEMENT
            Current implementation of tktray is designed to present an
            interface of a usual toplevel window, but there are some important
            differences (some of  them may  come  up later). System Tray
            specification is based on XEMBED protocol, and the later has a
            problem: when the embedder crashes, nothing can prevent
            embedded windows from destruction.  Since tktray 1.3, no explicit
            icon recreation code is required on Tcl level. The widget was
            split in two: one represented  by  a  caller-specified name, and
            another (currently $path.inner) that exists only when a tray is
            available (and dies and comes back and so on).
            This solution has some disadvantages as well.  User-created widget
            is not mapped at all, thus it can't be used any more as a parent
            for  other  widgets, showing them instead of an image. A temporal
            inner window, however, may contain widgets.

            This version introduces three virtual events: <<IconCreate>>
            <<IconConfigure>> and <<IconDestroy>>. <<IconCreate>> is
            generated when docking is requesting for an icon.
            <<IconConfigure>> is generated when an icon window is resized or
            changed in some other way.  <<IconDestroy>> is generated when an
            icon is destroyed due to panel crash or undocked with unsetting
            -docked option.'''

        if not master:
            if Tkinter._support_default_root:
                if not Tkinter._default_root:
                    Tkinter._default_root = Tkinter.Tk()
                master = Tkinter._default_root
        self.TktrayVersion = master.tk.call('package', 'require', 'tktray')

        # stolen from Tkinter.Toplevel
        if kw:
            cnf = Tkinter._cnfmerge((cnf, kw))
        extra = ()
        for wmkey in ['screen', 'class_', 'class', 'visible', 'colormap']:
            if cnf.has_key(wmkey):
                val = cnf[wmkey]
                # TBD: a hack needed because some keys
                # are not valid as keyword arguments
                if wmkey[-1] == '_': opt = '-'+wmkey[:-1]
                else: opt = '-'+wmkey
                extra = extra + (opt, val)
                del cnf[wmkey]
        Tkinter.BaseWidget.__init__(self, master, 'tktray::icon', cnf, {}, extra)
        self.protocol("WM_DELETE_WINDOW", self.destroy)

        self.menu = None
        if menu:
            self.menu = Tkinter.Menu(self, tearoff=0)
            self.bind('<3>', self._postmenu)
        self.tooltip = None
        if tooltip:
            self.tooltip = ToolTip(self, text=tooltip)

    def balloon(self, message='', timeout=None):
        '''Post a message that any decent tray implementation would show
        alongside the icon (or a place allocated for it). The message will
        disappear automatically after $msec_timeout milliseconds.
        Unfortunately, there is absolutely no way to know if the tray supports
        this feature, so don't rely on it for any critical information to be
        delivered. When no timeout or zero timeout is given, the message
        should not be hidden without user action (usually a mouse click).
        The return value is an integer, a message handle that may be used for
        cancelling the message before timeout expiration, or zero if there is
        currently no system tray to handle the request.'''
        return int(self.tk.call(self._w, 'balloon', message, timeout))


    def bbox(self):
        '''Get the list of left, top, right and bottom coordinates of the icon
        relative to the root window of the icon's screen. This command should
        be used in preference to winfo rootx and winfo rooty to get icon
        location, though the latter may seem to work on your system. Bounding
        box information is updated asynchronously. Don't rely on its
        correctness on script startup, just after icon creation. This command
        is for event handlers: on <ButtonPress-3> you'd like to have a popup
        menu, but where it should be posted? Use %W bbox to determine it right
        at the moment when a click happened.'''
        return self._getints(self.tk.call(self._w, 'bbox')) or None

    def cancel(self, message_handle):
        '''Cancel an earlier-posted balloon message. Zero message_handle is
        silently ignored. If there is no message with this handle, or its
        timeout has expired, or it was posted to another system tray and is
        unknow to the current one, nothing bad should happen (but it depends
        on the tray implementation).'''
        self.tk.call(self._w, 'cancel', message_handle)

    def docked(self):
        '''Query icon if it's currently embedded into some system tray.
        Invisible icons may be docked too (and tktray strives for it). If
        this method returns false, the icon is not visible to anyone, and no
        chance to get balloon messages displayed.'''
        return (self.tk.getboolean(
                self.tk.call(self._w, 'docked')) and True) or False

    def orientation(self):
        '''Query orientation of a system tray that is currently embedding
        the icon.'''
        return self.tk.call(self._w, 'orientation')
    orient = orientation

    def _postmenu(self, event):
        w, h = self.menu.winfo_reqwidth(), self.menu.winfo_reqheight()
        x0, y0, x1, y1 = self.bbox()
        # get the coords for the popup menu; we want it to the mouse pointer's
        # left and above the pointer in case the taskbar is on the bottom of the
        # screen, else below the pointer; add 1 pixel towards the pointer in each
        # dimension, so the pointer is '*inside* the menu when the button is being
        # released, so the menu will not unpost on the initial button-release event
        if y0 > self.winfo_screenheight() / 2:
            # assume the panel is at the bottom of the screen
            x, y = event.x_root - w + 1, event.y_root - h + 1
        else:
            x, y = event.x_root - w + 1, event.y_root - 1
        # make sure that x is not outside the screen
        if x < 5:
            x = 5
        self.menu.tk_popup(x, y)

###############################################################################
###############################################################################

# ToolTip class, taken from the tkinter wiki, with the coords() method
# modified for use with tray icons

class ToolTip:
    def __init__(self, master, text='Your text here', delay=1500, **opts):
        self.master = master
        self._opts = {'anchor':'center', 'bd':1, 'bg':'lightyellow', 'delay':delay, 'fg':'black',
                      'font':None, 'justify':'left', 'padx':4, 'pady':2,
                      'relief':'solid', 'state':'normal', 'text':text, 'textvariable':None,
                      'width':0, 'wraplength':150}
        self.configure(**opts)
        self._tipwindow = None
        self._id = None
        self._id1 = self.master.bind("<Enter>", self.enter, '+')
        self._id2 = self.master.bind("<Leave>", self.leave, '+')
        self._id3 = self.master.bind("<ButtonPress>", self.leave, '+')

    def configure(self, **opts):
        for key in opts:
            if self._opts.has_key(key):
                self._opts[key] = opts[key]
            else:
                raise KeyError, 'Unknown option: "%s"' %key

    ##----these methods handle the callbacks on "<Enter>", "<Leave>" and "<Motion>"---------------##
    ##----events on the parent widget; override them if you want to change the widget's behavior--##

    def enter(self, event=None):
        self._schedule()

    def leave(self, event=None):
        self._unschedule()
        self._hide()

    ##------the methods that do the work:---------------------------------------------------------##

    def _schedule(self):
        self._unschedule()
        if self._opts['state'] == 'disabled':
            return
        self._id = self.master.after(self._opts['delay'], self._show)

    def _unschedule(self):
        id = self._id
        self._id = None
        if id:
            self.master.after_cancel(id)

    def _show(self):
        if self._opts['state'] == 'disabled':
            self._unschedule()
            return
        if not self._tipwindow:
            self._tipwindow = tw = Tkinter.Toplevel(self.master)
            # hide the window until we know the geometry
            tw.withdraw()
            tw.wm_overrideredirect(1)

            if tw.tk.call("tk", "windowingsystem") == 'aqua':
                tw.tk.call("::tk::unsupported::MacWindowStyle", "style", tw._w, "help", "none")

            self.create_contents()
            tw.update_idletasks()
            x, y = self.coords()
            tw.wm_geometry("+%d+%d" % (x, y))
            tw.deiconify()

    def _hide(self):
        tw = self._tipwindow
        self._tipwindow = None
        if tw:
            tw.destroy()
    ##----these methods might be overridden in derived classes:----------------------------------##

    def coords(self):
        # The tip window must be completely outside the master widget;
        # otherwise when the mouse enters the tip window we get
        # a leave event and it disappears, and then we get an enter
        # event and it reappears, and so on forever :-(
        x0, y0, x1, y1 = self.master.bbox()
        tw = self._tipwindow
        twx, twy = tw.winfo_reqwidth(), tw.winfo_reqheight()
        w, h = tw.winfo_screenwidth(), tw.winfo_screenheight()

        # as x coord simply use x1, just make sure we're inside the screen
        if x1 < 0:
            x1 = 0
        elif x1 + twx > w:
            x1 = w - twx

        # put the tooltip below the icon no matter if the tray is at the
        # bottom or at the top of the screen
        y = y1 + 3
        # make sure y is inside the screen
        if y + twy > h - 3:
            y = h - twy - 3
        return x1, y

    def create_contents(self):
        opts = self._opts.copy()
        for opt in ('delay', 'state'):
            del opts[opt]
        label = Tkinter.Label(self._tipwindow, **opts)
        label.pack()

###############################################################################
###############################################################################


if __name__ == '__main__':
    root = Tkinter.Tk()
    root.withdraw()
    root.img = Tkinter.PhotoImage(file="smiley.gif")
    icon = Icon(image=root.img, menu=1, tooltip='bli bla blubb')
    icon.tooltip.configure(delay=200)
    icon.menu.add_command(label='Quit', command=icon.quit)
    icon.balloon('foobarbaz')# does not work here with IceWm
    print 'version:', icon.TktrayVersion
    print 'docked:', icon.docked()
    print 'orient:', icon.orient()
    print 'bbox:', icon.bbox()
    root.mainloop()

==> un-applet_1.5_all.tar.bz2: un-applet_1.5_all/usr/share/un-applet/TkTray.py <==
# -*- coding: utf-8 -*-

import Tkinter
'''Tktray  is  an extension that is able to create system tray icons.
It follows http://www.freedesktop.org specifications when looking up
the system tray manager. This protocol is supported by modern versions
of KDE and Gnome panels, and by some other panel-like application.'''


class Icon(Tkinter.BaseWidget, Tkinter.Wm):
    def __init__(self, master=None, menu=True, tooltip=None, cnf={}, **kw):
        '''Create a new icon for the system tray. The application managing the
        system tray is notified about the new icon. It normally results in the
        icon being added to the tray. If there is no system tray at the icon
        creation time, the icon will be invisible. When a new system tray
        appears, the icon will be added to it. Since tktray 1.3, if the tray
        crashes and destroys your icon, it will be recreated on a new system
        tray when it's available.
        OPTIONS:
        class_
            WM_CLASS attribute for icon window. Tray manager may use class
            name to remember icon position or other attributes. This name may
            be used for event binding as well. For now, real icon window is
            distinct from the user-specified widget: it may be recreated and
            destroyed several times during icon lifetime, when a system tray
            crashes, terminates, disappears or appears. However, tktray tries
            to forward click and motion events from this inner window to user
            widget, so event bindings on widget name should work as they used
            to. This option applies to a real icon window, not to a
            user-visible widget, so don't rely on it to set widget defaults
            from an option database: the standard "TrayIcon" class name is
            used for it.
        docked
            boolean indicating whether the real icon window should be embedded
            into a tray when it exists. Think of it as a heavier version of
            -visible option: there is a guarantee that no place for icon will
            be reserved on any tray.
        image
            image to show in the system tray. Since tktray 1.3, image type
            PhotoImage is not mandatory anymore. Icon will be automatically
            redrawn on any image modifications. For Tk, deleting an image and
            creating an image with the same name later is a kind of image
            modification, and tktray follows this convention. Photo image
            operations that modify existing image content are another example
            of events triggering redisplay. Requested size for icon is set
            according to the image's width and height, but obeying
            (or disobeying) this request is left for the tray.
        menu
            boolean value indicating whether a context menu for the icon
            should be created on initialization. If True a menu is created
            and will pop up on <Button-3> events over the tray icon. The menu
            is of the type Tkinter.Menu and can be accessed through the
            tray icon's menu attribute.
        shape
            used to put a nonrectangular shape on an icon window.
            Ignored for compatibility.
        visible
            boolean value indicating whether the icon must be visible. The
            system tray manager continues to manage the icon whether it is
            visible or not. Thus when invisible icon becomes visible, its
            position on the system tray is likely to remain the same. Tktray
            currently tries to find a tray and embed into it as soon as
            possible, whether -visible is true or not. _XEMBED_INFO property
            is set for embedded window: a tray should show or hide an icon
            depending on this property. There may be, and indeed are,
            incomplete tray implementations ignoring _XEMBED_INFO
            (ex. docker). Gnome-panel "unmaps" an icon by making it one pixel
            wide, that might to be what you expect. For those implementations,
            the place for an icon will be reserved but no image will be
            displayed: tktray takes care of it. Tktray also blocks mouse event
            forwarding for invisible icons, so you may be confident that no
            <Button> bindings will be invoked at this time.
        WINDOW MANAGEMENT
            Current implementation of tktray is designed to present an
            interface of a usual toplevel window, but there are some important
            differences (some of  them may  come  up later). System Tray
            specification is based on XEMBED protocol, and the later has a
            problem: when the embedder crashes, nothing can prevent
            embedded windows from destruction.  Since tktray 1.3, no explicit
            icon recreation code is required on Tcl level. The widget was
            split in two: one represented  by  a  caller-specified name, and
            another (currently $path.inner) that exists only when a tray is
            available (and dies and comes back and so on).
            This solution has some disadvantages as well.  User-created widget
            is not mapped at all, thus it can't be used any more as a parent
            for  other  widgets, showing them instead of an image. A temporal
            inner window, however, may contain widgets.

            This version introduces three virtual events: <<IconCreate>>
            <<IconConfigure>> and <<IconDestroy>>. <<IconCreate>> is
            generated when docking is requesting for an icon.
            <<IconConfigure>> is generated when an icon window is resized or
            changed in some other way.  <<IconDestroy>> is generated when an
            icon is destroyed due to panel crash or undocked with unsetting
            -docked option.'''

        if not master:
            if Tkinter._support_default_root:
                if not Tkinter._default_root:
                    Tkinter._default_root = Tkinter.Tk()
                master = Tkinter._default_root
        self.TktrayVersion = master.tk.call('package', 'require', 'tktray')

        # stolen from Tkinter.Toplevel
        if kw:
            cnf = Tkinter._cnfmerge((cnf, kw))
        extra = ()
        for wmkey in ['screen', 'class_', 'class', 'visible', 'colormap']:
            if cnf.has_key(wmkey):
                val = cnf[wmkey]
                # TBD: a hack needed because some keys
                # are not valid as keyword arguments
                if wmkey[-1] == '_': opt = '-'+wmkey[:-1]
                else: opt = '-'+wmkey
                extra = extra + (opt, val)
                del cnf[wmkey]
        Tkinter.BaseWidget.__init__(self, master, 'tktray::icon', cnf, {}, extra)
        self.protocol("WM_DELETE_WINDOW", self.destroy)

        self.menu = None
        if menu:
            self.menu = Tkinter.Menu(self, tearoff=0)
            self.bind('<3>', self._postmenu)
        self.tooltip = None
        if tooltip:
            self.tooltip = ToolTip(self, text=tooltip)

    def balloon(self, message='', timeout=None):
        '''Post a message that any decent tray implementation would show
        alongside the icon (or a place allocated for it). The message will
        disappear automatically after $msec_timeout milliseconds.
        Unfortunately, there is absolutely no way to know if the tray supports
        this feature, so don't rely on it for any critical information to be
        delivered. When no timeout or zero timeout is given, the message
        should not be hidden without user action (usually a mouse click).
        The return value is an integer, a message handle that may be used for
        cancelling the message before timeout expiration, or zero if there is
        currently no system tray to handle the request.'''
        return int(self.tk.call(self._w, 'balloon', message, timeout))

    def bbox(self):
        '''Get the list of left, top, right and bottom coordinates of the icon
        relative to the root window of the icon's screen. This command should
        be used in preference to winfo rootx and winfo rooty to get icon
        location, though the latter may seem to work on your system. Bounding
        box information is updated asynchronously. Don't rely on its
        correctness on script startup, just after icon creation. This command
        is for event handlers: on <ButtonPress-3> you'd like to have a popup
        menu, but where it should be posted? Use %W bbox to determine it right
        at the moment when a click happened.'''
        return self._getints(self.tk.call(self._w, 'bbox')) or None

    def cancel(self, message_handle):
        '''Cancel an earlier-posted balloon message. Zero message_handle is
        silently ignored. If there is no message with this handle, or its
        timeout has expired, or it was posted to another system tray and is
        unknow to the current one, nothing bad should happen (but it depends
        on the tray implementation).'''
        self.tk.call(self._w, 'cancel', message_handle)

    def docked(self):
        '''Query icon if it's currently embedded into some system tray.
        Invisible icons may be docked too (and tktray strives for it). If
        this method returns false, the icon is not visible to anyone, and no
        chance to get balloon messages displayed.'''
        return (self.tk.getboolean(
                self.tk.call(self._w, 'docked')) and True) or False

    def orientation(self):
        '''Query orientation of a system tray that is currently embedding
        the icon.'''
        return self.tk.call(self._w, 'orientation')
    orient = orientation

    def _postmenu(self, event):
        w, h = self.menu.winfo_reqwidth(), self.menu.winfo_reqheight()
        x0, y0, x1, y1 = self.bbox()
        # get the coords for the popup menu; we want it to the mouse pointer's
        # left and above the pointer in case the taskbar is on the bottom of the
        # screen, else below the pointer; add 1 pixel towards the pointer in each
        # dimension, so the pointer is '*inside* the menu when the button is being
        # released, so the menu will not unpost on the initial button-release event
        if y0 > self.winfo_screenheight() / 2:
            # assume the panel is at the bottom of the screen
            x, y = event.x_root - w + 1, event.y_root - h + 1
        else:
            x, y = event.x_root - w + 1, event.y_root - 1
        # make sure that x is not outside the screen
        if x < 5:
            x = 5
        self.menu.tk_popup(x, y)

###############################################################################
###############################################################################

# ToolTip class, taken from the tkinter wiki, with the coords() method
# modified for use with tray icons

class ToolTip:
    def __init__(self, master, text='Your text here', delay=1500, **opts):
        self.master = master
        self._opts = {'anchor':'center', 'bd':1, 'bg':'lightyellow', 'delay':delay, 'fg':'black',
                      'font':None, 'justify':'left', 'padx':4, 'pady':2,
                      'relief':'solid', 'state':'normal', 'text':text, 'textvariable':None,
                      'width':0, 'wraplength':150}
        self.configure(**opts)
        self._tipwindow = None
        self._id = None
        self._id1 = self.master.bind("<Enter>", self.enter, '+')
        self._id2 = self.master.bind("<Leave>", self.leave, '+')
        self._id3 = self.master.bind("<ButtonPress>", self.leave, '+')

    def configure(self, **opts):
        for key in opts:
            if self._opts.has_key(key):
                self._opts[key] = opts[key]
            else:
                raise KeyError, 'Unknown option: "%s"' %key

    ##----these methods handle the callbacks on "<Enter>", "<Leave>" and "<Motion>"---------------##
    ##----events on the parent widget; override them if you want to change the widget's behavior--##

    def enter(self, event=None):
        self._schedule()

    def leave(self, event=None):
        self._unschedule()
        self._hide()

    ##------the methods that do the work:---------------------------------------------------------##

    def _schedule(self):
        self._unschedule()
        if self._opts['state'] == 'disabled':
            return
        self._id = self.master.after(self._opts['delay'], self._show)

    def _unschedule(self):
        id = self._id
        self._id = None
        if id:
            self.master.after_cancel(id)

    def _show(self):
        if self._opts['state'] == 'disabled':
            self._unschedule()
            return
        if not self._tipwindow:
            self._tipwindow = tw = Tkinter.Toplevel(self.master)
            # hide the window until we know the geometry
            tw.withdraw()
            tw.wm_overrideredirect(1)

            if tw.tk.call("tk", "windowingsystem") == 'aqua':
                tw.tk.call("::tk::unsupported::MacWindowStyle", "style", tw._w, "help", "none")

            self.create_contents()
            tw.update_idletasks()
            x, y = self.coords()
            tw.wm_geometry("+%d+%d" % (x, y))
            tw.deiconify()

    def _hide(self):
        tw = self._tipwindow
        self._tipwindow = None
        if tw:
            tw.destroy()
    ##----these methods might be overridden in derived classes:----------------------------------##

    def coords(self):
        # The tip window must be completely outside the master widget;
        # otherwise when the mouse enters the tip window we get
        # a leave event and it disappears, and then we get an enter
        # event and it reappears, and so on forever :-(
        x0, y0, x1, y1 = self.master.bbox()
        tw = self._tipwindow
        twx, twy = tw.winfo_reqwidth(), tw.winfo_reqheight()
        sw, sh = tw.winfo_screenwidth(), tw.winfo_screenheight()
        # put the tooltip below the icon no matter if the tray is at the
        # bottom or at the top of the screen
        y = y1 + 1
        # make sure y is inside the screen
        if y + twy > sh:
            y = sh - twy - 3
        # by default put the tip to the icon's right
        x = x1 + 1
        # y might be inside the icon, so we have to make sure that x is outside
        # so if the tip would partially be outside the screen move it entirely
        # to the icon's left
        if x + twx > sw:
            x = x0 - twx - 1
        return x, y

    def create_contents(self):
        opts = self._opts.copy()
        for opt in ('delay', 'state'):
            del opts[opt]
        label = Tkinter.Label(self._tipwindow, **opts)
        label.pack()

###############################################################################
###############################################################################


if __name__ == '__main__':
    root = Tkinter.Tk()
    root.withdraw()
    root.img = Tkinter.PhotoImage(file="smiley.gif")
    icon = Icon(image=root.img, menu=1, tooltip='bli bla blubb')
    icon.tooltip.configure(delay=200)
    icon.menu.add_command(label='Quit', command=icon.quit)
    icon.balloon('foobarbaz')# does not work here with IceWm
    print 'version:', icon.TktrayVersion
    print 'docked:', icon.docked()
    print 'orient:', icon.orient()
    print 'bbox:', icon.bbox()
    root.mainloop()
